Module: Aws::Uxc

Defined in:
lib/aws-sdk-uxc/endpoint_parameters.rb,
lib/aws-sdk-uxc/plugins/endpoints.rb,
lib/aws-sdk-uxc/endpoint_provider.rb,
lib/aws-sdk-uxc/client_api.rb,
lib/aws-sdk-uxc/endpoints.rb,
lib/aws-sdk-uxc/resource.rb,
lib/aws-sdk-uxc/waiters.rb,
lib/aws-sdk-uxc/errors.rb,
lib/aws-sdk-uxc/client.rb,
lib/aws-sdk-uxc/types.rb,
lib/aws-sdk-uxc.rb

Overview

This module provides support for AWS User Experience Customization. This module is available in the ‘aws-sdk-uxc` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

uxc = Aws::Uxc::Client.new
resp = uxc.(params)

See Client for more information.

# Errors

Errors returned from AWS User Experience Customization are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::Uxc::Errors::ServiceError
  # rescues all AWS User Experience Customization API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.2.0'