Class: Aws::Uxc::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Uxc::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-uxc/client.rb,
sig/client.rbs
Overview
An API client for Uxc. To construct a client, you need to configure a :region and :credentials.
client = Aws::Uxc::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetAccountCustomizationsResponseSuccess, _ListServicesResponseSuccess, _UpdateAccountCustomizationsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_account_customizations(params = {}) ⇒ Types::GetAccountCustomizationsOutput
Returns the current account customization settings, including account color, visible services, and visible Regions.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
Returns a paginated list of Amazon Web Services service identifiers that you can use as values for the
visibleServicessetting in [UpdateAccountCustomizations][1]. -
#update_account_customizations(params = {}) ⇒ Types::UpdateAccountCustomizationsOutput
Updates one or more account customization settings.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-uxc/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
731 732 733 |
# File 'lib/aws-sdk-uxc/client.rb', line 731 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
734 735 736 |
# File 'lib/aws-sdk-uxc/client.rb', line 734 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'lib/aws-sdk-uxc/client.rb', line 704 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Uxc') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-uxc' context[:gem_version] = '1.4.0' Seahorse::Client::Request.new(handlers, context) end |
#get_account_customizations(params = {}) ⇒ Types::GetAccountCustomizationsOutput
Returns the current account customization settings, including account
color, visible services, and visible Regions. Settings that you have
not configured return their default values: visible Regions and
visible services return null, and account color returns none.
visibleServices and visibleRegions settings control only the
appearance of services and Regions in the Amazon Web Services
Management Console. They do not restrict access through the CLI, SDKs,
or other APIs.
88 |
# File 'sig/client.rbs', line 88
def get_account_customizations: (
|
#list_services(params = {}) ⇒ Types::ListServicesOutput
Returns a paginated list of Amazon Web Services service identifiers
that you can use as values for the visibleServices setting in
UpdateAccountCustomizations. The available services vary by
Amazon Web Services partition. Use pagination to retrieve all results.
visibleServices setting controls only the appearance of services
in the Amazon Web Services Management Console. It does not restrict
access through the CLI, SDKs, or other APIs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
98 |
# File 'sig/client.rbs', line 98
def list_services: (
|
#update_account_customizations(params = {}) ⇒ Types::UpdateAccountCustomizationsOutput
Updates one or more account customization settings. You can update
account color, visible services, and visible Regions in a single
request. Only the settings that you include in the request body are
modified. Omitted settings remain unchanged. To reset a setting to its
default behavior, set the value to null for visible Regions and
visible services, or none for account color. This operation is
idempotent.
visibleServices and visibleRegions settings control only the
appearance of services and Regions in the Amazon Web Services
Management Console. They do not restrict access through the CLI, SDKs,
or other APIs.
111 |
# File 'sig/client.rbs', line 111
def update_account_customizations: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
724 725 726 |
# File 'lib/aws-sdk-uxc/client.rb', line 724 def waiter_names [] end |