Class: Aws::Uxc::Types::GetAccountCustomizationsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-uxc/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_colorString

The account color preference. A value of ‘none` indicates that you have not set a color.

Returns:

  • (String)


71
72
73
74
75
76
77
# File 'lib/aws-sdk-uxc/types.rb', line 71

class GetAccountCustomizationsOutput < Struct.new(
  :account_color,
  :visible_services,
  :visible_regions)
  SENSITIVE = []
  include Aws::Structure
end

#visible_regionsArray<String>

The list of Amazon Web Services Region codes that are visible to the account in the Amazon Web Services Management Console. A value of ‘null` indicates that you have not configured this feature and all Regions are visible. For a list of valid Region codes, see [Amazon Web Services Regions].

[1]: docs.aws.amazon.com/global-infrastructure/latest/regions/aws-regions.html

Returns:

  • (Array<String>)


71
72
73
74
75
76
77
# File 'lib/aws-sdk-uxc/types.rb', line 71

class GetAccountCustomizationsOutput < Struct.new(
  :account_color,
  :visible_services,
  :visible_regions)
  SENSITIVE = []
  include Aws::Structure
end

#visible_servicesArray<String>

The list of Amazon Web Services service identifiers that are visible to the account in the Amazon Web Services Management Console. A value of ‘null` indicates that you have not configured this feature and all services are visible. For valid service identifiers, call [ListServices].

[1]: docs.aws.amazon.com/awsconsolehelpdocs/latest/APIReference/API_ListServices.html

Returns:

  • (Array<String>)


71
72
73
74
75
76
77
# File 'lib/aws-sdk-uxc/types.rb', line 71

class GetAccountCustomizationsOutput < Struct.new(
  :account_color,
  :visible_services,
  :visible_regions)
  SENSITIVE = []
  include Aws::Structure
end