Class: Aws::Uxc::Types::ListServicesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-uxc/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


104
105
106
107
108
109
# File 'lib/aws-sdk-uxc/types.rb', line 104

class ListServicesInput < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for retrieving the next page of results. Use the nextToken value from a previous response.

Returns:

  • (String)


104
105
106
107
108
109
# File 'lib/aws-sdk-uxc/types.rb', line 104

class ListServicesInput < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end