Class: Aws::Uxc::Types::ListServicesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Uxc::Types::ListServicesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-uxc/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for retrieving the next page of results.
-
#services ⇒ Array<String>
The list of available Amazon Web Services service identifiers.
Instance Attribute Details
#next_token ⇒ String
The token for retrieving the next page of results. This value is
null when no more results are available.
122 123 124 125 126 127 |
# File 'lib/aws-sdk-uxc/types.rb', line 122 class ListServicesOutput < Struct.new( :next_token, :services) SENSITIVE = [] include Aws::Structure end |
#services ⇒ Array<String>
The list of available Amazon Web Services service identifiers.
122 123 124 125 126 127 |
# File 'lib/aws-sdk-uxc/types.rb', line 122 class ListServicesOutput < Struct.new( :next_token, :services) SENSITIVE = [] include Aws::Structure end |