Class: Aws::Uxc::Types::UpdateAccountCustomizationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-uxc/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_colorString

The account color preference to set. Set to ‘none` to reset to the default (no color).

Returns:

  • (String)


172
173
174
175
176
177
178
# File 'lib/aws-sdk-uxc/types.rb', line 172

class UpdateAccountCustomizationsInput < Struct.new(
  :account_color,
  :visible_services,
  :visible_regions)
  SENSITIVE = []
  include Aws::Structure
end

#visible_regionsArray<String>

The list of Amazon Web Services Region codes to make visible in the Amazon Web Services Management Console. Set to ‘null` to reset to the default, which makes all Regions visible. For a list of valid Region codes, see [Amazon Web Services Regions].

[1]: docs.aws.amazon.com/global-infrastructure/latest/regions/aws-regions.html

Returns:

  • (Array<String>)


172
173
174
175
176
177
178
# File 'lib/aws-sdk-uxc/types.rb', line 172

class UpdateAccountCustomizationsInput < Struct.new(
  :account_color,
  :visible_services,
  :visible_regions)
  SENSITIVE = []
  include Aws::Structure
end

#visible_servicesArray<String>

The list of Amazon Web Services service identifiers to make visible in the Amazon Web Services Management Console. Set to ‘null` to reset to the default, which makes all services visible. For valid service identifiers, call [ListServices].

[1]: docs.aws.amazon.com/awsconsolehelpdocs/latest/APIReference/API_ListServices.html

Returns:

  • (Array<String>)


172
173
174
175
176
177
178
# File 'lib/aws-sdk-uxc/types.rb', line 172

class UpdateAccountCustomizationsInput < Struct.new(
  :account_color,
  :visible_services,
  :visible_regions)
  SENSITIVE = []
  include Aws::Structure
end